@@ -1,9 +1,9 @@
 # --
-# Copyright (C) 2001-2018 OTRS AG, https://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
-# the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see https://www.gnu.org/licenses/gpl-3.0.txt.
+# the enclosed file COPYING for license information (AGPL). If you
+# did not receive this file, see http://www.gnu.org/licenses/agpl.txt.
 # --
 
 package Kernel::GenericInterface::Mapping::Simple;
@@ -80,7 +80,7 @@ sub new {
 =item Map()
 
 provides 1:1 and regex mapping for keys and values
-also the use of a default for unmapped keys and values is possible
+also the use of a default for keys and values that were not mapped is possible
 
 we need the config to be in the following format
 
@@ -245,7 +245,7 @@ sub Map {
         # check if we have a value mapping for the specific key
         my $ValueMap;
         if ( $Config->{ValueMap} && $Config->{ValueMap}->{$NewKey} ) {
-            $ValueMap = $Config->{ValueMap}->{$NewKey};
+            $ValueMap = $Config->{ValueMap}->{$NewKey}
         }
 
         if ($ValueMap) {
@@ -474,10 +474,10 @@ sub _ConfigCheck {
 
 =head1 TERMS AND CONDITIONS
 
-This software is part of the OTRS project (L<https://otrs.org/>).
+This software is part of the OTRS project (L<http://otrs.org/>).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
-the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see L<https://www.gnu.org/licenses/gpl-3.0.txt>.
+the enclosed file COPYING for license information (AGPL). If you
+did not receive this file, see L<http://www.gnu.org/licenses/agpl.txt>.
 
 =cut
