@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -307,8 +307,6 @@ sub _DynamicFieldsListShow {
         );
     }
 
-    my $MaxFieldOrder = 0;
-
     # check if at least 1 dynamic field is registered in the system
     if ( $Param{Total} ) {
 
@@ -368,11 +366,6 @@ sub _DynamicFieldsListShow {
                         },
                     );
                 }
-
-                # set MaxFieldOrder
-                if ( int $DynamicFieldData->{FieldOrder} > int $MaxFieldOrder ) {
-                    $MaxFieldOrder = $DynamicFieldData->{FieldOrder}
-                }
             }
         }
     }
@@ -388,7 +381,7 @@ sub _DynamicFieldsListShow {
     $LayoutObject->Block(
         Name => 'MaxFieldOrder',
         Data => {
-            MaxFieldOrder => $MaxFieldOrder,
+            MaxFieldOrder => scalar @{ $Param{DynamicFields} },
         },
     );
 
