@@ -1,5 +1,5 @@
 # --
-# Copyright (C) 2001-2016 OTRS AG, http://otrs.com/
+# Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (AGPL). If you
@@ -94,12 +94,12 @@ sub Run {
         my %Not;
 
         for my $Number ( 1 .. $ConfigObject->Get('PostmasterHeaderFieldCount') ) {
-            if ( $GetParam{"MatchHeader$Number"} && $GetParam{"MatchValue$Number"} ) {
+            if ( $GetParam{"MatchHeader$Number"} && length $GetParam{"MatchValue$Number"} ) {
                 $Match{ $GetParam{"MatchHeader$Number"} } = $GetParam{"MatchValue$Number"};
                 $Not{ $GetParam{"MatchHeader$Number"} }   = $GetParam{"MatchNot$Number"};
             }
 
-            if ( $GetParam{"SetHeader$Number"} && $GetParam{"SetValue$Number"} ) {
+            if ( $GetParam{"SetHeader$Number"} && length $GetParam{"SetValue$Number"} ) {
                 $Set{ $GetParam{"SetHeader$Number"} } = $GetParam{"SetValue$Number"};
             }
         }
@@ -124,7 +124,7 @@ sub Run {
             my $InvalidCount = 0;
             for my $SetKey ( sort keys %Set ) {
                 $InvalidCount++;
-                if ( !defined $Set{$SetKey} ) {
+                if ( !length $Set{$SetKey} ) {
                     $Errors{"SetHeader${InvalidCount}Invalid"} = 'ServerError';
                     $Errors{"SetValue${InvalidCount}Invalid"}  = 'ServerError';
                 }
@@ -140,11 +140,20 @@ sub Run {
             $Errors{"NameInvalid"} = 'ServerError';
         }
 
+        # If it's not edit action, verify there is no filters with same name.
+        if ( $Name ne $OldName ) {
+            my %Data = $PostMasterFilter->FilterGet( Name => $Name );
+            if (%Data) {
+                $Errors{"NameInvalid"} = 'ServerError';
+            }
+        }
+
         if (%Errors) {
             return $Self->_MaskUpdate(
                 Name => $Name,
                 Data => {
                     %Errors,
+                    OldName        => $OldName,
                     Name           => $Name,
                     Set            => \%Set,
                     Match          => \%Match,
@@ -216,7 +225,7 @@ sub _MaskUpdate {
     my $Counter = 0;
     if ( $Data{Match} ) {
         for my $MatchKey ( sort keys %{ $Data{Match} } ) {
-            if ( $MatchKey && $Data{Match}->{$MatchKey} ) {
+            if ( $MatchKey && length $Data{Match}->{$MatchKey} ) {
                 $Counter++;
                 $Data{"MatchValue$Counter"}  = $Data{Match}->{$MatchKey};
                 $Data{"MatchHeader$Counter"} = $MatchKey;
@@ -227,7 +236,7 @@ sub _MaskUpdate {
     $Counter = 0;
     if ( $Data{Set} ) {
         for my $SetKey ( sort keys %{ $Data{Set} } ) {
-            if ( $SetKey && $Data{Set}->{$SetKey} ) {
+            if ( $SetKey && length $Data{Set}->{$SetKey} ) {
                 $Counter++;
                 $Data{"SetValue$Counter"}  = $Data{Set}->{$SetKey};
                 $Data{"SetHeader$Counter"} = $SetKey;
@@ -304,11 +313,16 @@ sub _MaskUpdate {
         HTMLQuote   => 1,
     );
 
+    my $OldName = $Data{Name};
+    if ( $Param{Data}->{NameInvalid} ) {
+        $OldName = $Data{OldName};
+    }
+
     $LayoutObject->Block(
         Name => 'OverviewUpdate',
         Data => {
             %Param, %Data,
-            OldName => $Data{Name},
+            OldName => $OldName,
         },
     );
 
