@@ -1,5 +1,5 @@
 // --
-// Copyright (C) 2001-2015 OTRS AG, http://otrs.com/
+// Copyright (C) 2001-2017 OTRS AG, http://otrs.com/
 // --
 // This software comes with ABSOLUTELY NO WARRANTY. For details, see
 // the enclosed file COPYING for license information (AGPL). If you
@@ -45,16 +45,34 @@ Core.UI.RichTextEditor = (function (TargetNS) {
      * @memberof Core.UI.RichTextEditor
      * @function
      * @returns {jQueryObject} FormID element.
+     * @param {jQueryObject} $EditorArea - The jQuery object of the element that has become a rich text editor.
      * @description
      *      Check in the window which hidden element has a name same to 'FormID' and return it like a JQuery object.
      */
-    function CheckFormID() {
+    function CheckFormID($EditorArea) {
         if (typeof $FormID === 'undefined') {
-            $FormID = $('input:hidden[name=FormID]');
+            $FormID = $EditorArea.closest('form').find('input:hidden[name=FormID]');
         }
         return $FormID;
     }
 
+    /**
+     * @private
+     * @name SerializeData
+     * @memberof Core.UI.RichTextEditor
+     * @function
+     * @return {string} query string of the data
+     * @param {Object} Data The data that should be converted
+     * @description Converts a given hash into a query string
+     */
+    function SerializeData(Data) {
+        var QueryString = '';
+        $.each(Data, function (Key, Value) {
+            QueryString += ';' + encodeURIComponent(Key) + '=' + encodeURIComponent(Value);
+        });
+        return QueryString;
+    }
+
     /**
      * @name Init
      * @memberof Core.UI.RichTextEditor
@@ -117,14 +135,13 @@ Core.UI.RichTextEditor = (function (TargetNS) {
         UserLanguage = Core.Config.Get('UserLanguage').replace(/_/, "-");
 
         // build URL for image upload
-        if (CheckFormID().length) {
+        if (CheckFormID($EditorArea).length) {
             UploadURL = Core.Config.Get('Baselink')
                     + 'Action='
                     + Core.Config.Get('RichText.PictureUploadAction', 'PictureUpload')
                     + '&FormID='
-                    + CheckFormID().val()
-                    + '&' + Core.Config.Get('SessionName')
-                    + '=' + Core.Config.Get('SessionID');
+                    + CheckFormID($EditorArea).val()
+                    + SerializeData(Core.App.GetSessionInformation());
         }
 
         /*eslint-disable camelcase */
@@ -136,19 +153,19 @@ Core.UI.RichTextEditor = (function (TargetNS) {
             width: Core.Config.Get('RichText.Width', 620),
             resize_minWidth: Core.Config.Get('RichText.Width', 620),
             height: Core.Config.Get('RichText.Height', 320),
-            removePlugins: CheckFormID().length ? 'elementspath,scayt,menubutton' : 'elementspath,scayt,menubutton,image2,uploadimage',
+            removePlugins: CheckFormID($EditorArea).length ? '' : 'image2,uploadimage',
             forcePasteAsPlainText: false,
             format_tags: 'p;h1;h2;h3;h4;h5;h6;pre',
             fontSize_sizes: '8px;10px;12px;16px;18px;20px;22px;24px;26px;28px;30px;',
-            extraAllowedContent: 'div table tr td th colgroup col img figure figcaption style[*]{*}',
+            extraAllowedContent: 'div[type]{*}; img[*]; col[width]; style[*]{*}; *[id](*)',
             enterMode: CKEDITOR.ENTER_BR,
             shiftEnterMode: CKEDITOR.ENTER_BR,
             contentsLangDirection: Core.Config.Get('RichText.TextDir', 'ltr'),
             disableNativeSpellChecker: false,
-            toolbar: CheckFormID().length ? Core.Config.Get('RichText.Toolbar') : Core.Config.Get('RichText.ToolbarWithoutImage'),
+            toolbar: CheckFormID($EditorArea).length ? Core.Config.Get('RichText.Toolbar') : Core.Config.Get('RichText.ToolbarWithoutImage'),
             filebrowserBrowseUrl: '',
             filebrowserUploadUrl: UploadURL,
-            extraPlugins: Core.Config.Get('RichText.SpellChecker') ? 'aspell,splitquote' : 'splitquote',
+            extraPlugins: Core.Config.Get('RichText.SpellChecker') ? 'aspell,splitquote,contextmenu_linkopen,preventimagepaste' : 'splitquote,contextmenu_linkopen,preventimagepaste',
             entities: false,
             skin: 'bootstrapck'
         });
